==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/SystemMenuentriesIdLocationsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemMenuentriesIdLocationsCountEndpoint import \
    SystemMenuentriesIdLocationsCountEndpoint
from pyconnectwise.endpoints.manage.SystemMenuentriesIdLocationsIdEndpoint import SystemMenuentriesIdLocationsIdEndpoint
from pyconnectwise.models.manage import MenuEntryLocation
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemMenuentriesIdLocationsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "locations", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            SystemMenuentriesIdLocationsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemMenuentriesIdLocationsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemMenuentriesIdLocationsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemMenuentriesIdLocationsIdEndpoint: The initialized SystemMenuentriesIdLocationsIdEndpoint object.
        """
        child = SystemMenuentriesIdLocationsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[MenuEntryLocation]:
        """
        Performs a GET request against the /system/menuEntries/{id}/locations endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MenuEntryLocation]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            MenuEntryLocation,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MenuEntryLocation]:
        """
        Performs a GET request against the /system/menuEntries/{id}/locations endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MenuEntryLocation]: The parsed response data.
        """
        return self._parse_many(MenuEntryLocation, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MenuEntryLocation:
        """
        Performs a POST request against the /system/menuEntries/{id}/locations endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MenuEntryLocation: The parsed response data.
        """
        return self._parse_one(MenuEntryLocation, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/SystemMenuentriesIdLocationsEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.SystemMenuentriesIdLocationsCountEndpoint import \
    SystemMenuentriesIdLocationsCountEndpoint
from pyconnectwise.endpoints.manage.SystemMenuentriesIdLocationsIdEndpoint import SystemMenuentriesIdLocationsIdEndpoint
from pyconnectwise.models.manage import MenuEntryLocation
from pyconnectwise.responses.paginated_response import PaginatedResponse


class SystemMenuentriesIdLocationsEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "locations", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            SystemMenuentriesIdLocationsCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> SystemMenuentriesIdLocationsIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized SystemMenuentriesIdLocationsIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            SystemMenuentriesIdLocationsIdEndpoint: The initialized SystemMenuentriesIdLocationsIdEndpoint object.
        """
        child = SystemMenuentriesIdLocationsIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[MenuEntryLocation]:
        """
        Performs a GET request against the /system/menuEntries/{id}/locations endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[MenuEntryLocation]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), MenuEntryLocation, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[MenuEntryLocation]:
        """
        Performs a GET request against the /system/menuEntries/{id}/locations endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[MenuEntryLocation]: The parsed response data.
        """
        return self._parse_many(MenuEntryLocation, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> MenuEntryLocation:
        """
        Performs a POST request against the /system/menuEntries/{id}/locations endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            MenuEntryLocation: The parsed response data.
        """
        return self._parse_one(MenuEntryLocation, super()._make_request("POST", data=data, params=params).json())
